package prompt.roles.data;

import java.util.Collection;
import java.util.HashSet;

/**
 * This class represents a set of dependencies.
 * 
 * @author Andrea Burattin
 * @author Marco Veluscek
 * @see Dependency
 */
public class DependencySet extends HashSet<Dependency> {

	private static final long serialVersionUID = -5264245620120060990L;

	/**
	 * This method can be used to retrieve a dependency from the current set
	 * 
	 * @param source the name of the source activity of the dependency
	 * @param target the name of the target activity of the dependency
	 * @return the dependency, or <tt>null</tt> if no dependency is found
	 */
	public Dependency search(String source, String target) {
		for(Dependency d : this) {
			if (d.getSourceActivity().equals(source) && d.getTargetActivity().equals(target)) {
				return d;
			}
		}
		return null;
	}
	
	/**
	 * This method the set of different and significative <code>w</code> values
	 * 
	 * @return the collection of values
	 */
	public  Collection<Double> getTw() {
		Collection<Double> Tw = new HashSet<Double>();
		for (Dependency d : this) {
			Tw.add(d.getDegreeOfNoHandover());
		}
		return Tw;
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		for (Dependency dependency : this) {
			sb.append(dependency.toString());
			sb.append("\n");
		}
		return sb.toString();
	}
}
